import requests
import nltk

nltk.download('punkt_tab', quiet=True)


class WeatherAPI:
    def __init__(self, api_key, city_database):
        self.api_key = api_key
        self.base_url = "https://api.openweathermap.org/data/2.5/weather"
        self.city_database = city_database

    def get_weather(self, city_candidate):
        """
        Pobiera pogodę dla miasta zweryfikowanego w bazie danych.
        city_candidate to już wyodrębniona nazwa miasta z inputu.
        """
        try:
            if not city_candidate:
                return "Sorry, I couldn't identify a valid city. Please try again."

            params = {"q": city_candidate, "appid": self.api_key, "units": "metric"}
            response = requests.get(self.base_url, params=params)
            data = response.json()

            if data["cod"] != 200:
                return f"Error: {data['message']}"

            temp = data["main"]["temp"]
            weather = data["weather"][0]["description"]
            city_name = data["name"]
            return f"The current weather in {city_name} is {temp}°C with {weather}."
        except Exception as e:
            print(e)
            return "Sorry, I couldn't fetch the weather data. Please try again."
