from intent_recognizer import IntentRecognizer
from weather_api import WeatherAPI
import random
import nltk
from thefuzz import process, fuzz

nltk.download('punkt', quiet=True)


class Chatbot:
    def __init__(self, api_key, city_database):
        self.weather_api = WeatherAPI(api_key, city_database)
        self.intent_recognizer = IntentRecognizer()
        self.city_database = city_database

    def extract_city_name(self, user_input):
        tokens = nltk.word_tokenize(user_input.lower())
        stopwords = ["weather", "in", "what's", "the", "tell", "me", "is", "what", "'s", "?"]
        filtered_tokens = [t for t in tokens if t not in stopwords]

        if not filtered_tokens:
            return ""

        candidate_city = " ".join(filtered_tokens)

        city_match = self.city_database.correct_city(candidate_city)
        if city_match:
            return city_match
        else:
            return ""

    def get_response(self, user_input):
        intent = self.intent_recognizer.recognize_intent(user_input.lower().strip())

        if intent == "greeting":
            return random.choice(["Hello!", "Hi there!", "Hey! How can I help you today?"])
        if intent == "farewell":
            return random.choice(["Goodbye! Take care.", "See you next time!", "Bye! Have a great day!"])
        if intent == "how_are_you":
            return random.choice(
                ["I'm just a bot, but I'm doing great!", "I'm here to help you. How can I assist you today?"])
        if intent == "weather":
            city_candidate = self.extract_city_name(user_input)
            return self.weather_api.get_weather(city_candidate)
        if intent == "help":
            return (
                "I can help you with the following:\n"
                "- Weather updates (e.g., 'What's the weather in Paris?')\n"
                "- Greet me (e.g., 'Hi')\n"
                "- Say goodbye (e.g., 'Bye')"
            )

        return "I'm sorry, I didn't understand that. Try asking for help by typing 'help'."
